import{U as s}from"./outputWidgets.04a14374.js";import{c as i,d}from"./index.8368b606.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="c37426c0-b9df-41a2-b4e6-ae5cf3ae24f0",e._sentryDebugIdIdentifier="sentry-dbid-c37426c0-b9df-41a2-b4e6-ae5cf3ae24f0")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:a,RangePicker:o}=i(d),y=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(t.name,t),e.component(r.name,r),e.component(a.name,a),e)});export{y as D,t as M,a as Q,o as R,r as W};
//# sourceMappingURL=dayjs.7f259218.js.map
