import"./outputWidgets.04a14374.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="851d0c56-b86f-4c9f-87ee-37c69f8b0871",e._sentryDebugIdIdentifier="sentry-dbid-851d0c56-b86f-4c9f-87ee-37c69f8b0871")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.311573c2.js.map
