import{cz as r}from"./outputWidgets.04a14374.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="879dcff9-feff-4f73-b942-77472e7e5b01",e._sentryDebugIdIdentifier="sentry-dbid-879dcff9-feff-4f73-b942-77472e7e5b01")}catch{}})();const t=(e,f)=>{r.error({message:e,description:f})};export{t as p};
//# sourceMappingURL=popupNotifcation.0c58993e.js.map
