import{d as y,r as i,G as x,b,eu as g,dh as v,e as d,eD as m,ev as D,t as w}from"./outputWidgets.04a14374.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="8a5a4c8c-c886-445a-aceb-49c698bac7ad",t._sentryDebugIdIdentifier="sentry-dbid-8a5a4c8c-c886-445a-aceb-49c698bac7ad")}catch{}})();const B={class:"text"},h=y({__name:"Tooltip",props:{text:{type:String,required:!0},left:{type:Number},top:{type:Number},fixed:{type:Boolean,default:!1}},setup(t){const e=t,s=i(Date.now()),p=()=>{s.value=Date.now()},n=i(null),u=()=>{var r,c,l;const o=(r=n.value)==null?void 0:r.getBoundingClientRect();if(!o)return{};const{x:a,y:_}=o;return s.value,{position:"fixed",top:`${_+((c=e.top)!=null?c:0)}px`,left:`${a+((l=e.left)!=null?l:0)}px`}},f=x(()=>{var o;return e.fixed?u():{left:`${(o=e.left)!=null?o:-14}px`,...e.top?{top:`${e.top}px`}:{}}});return(o,a)=>(b(),g("div",{ref_key:"tooltipBox",ref:n,class:"tooltip-box",onMouseenter:p},[v(o.$slots,"default",{},void 0,!0),d("div",{class:"tooltip",style:D(f.value)},[d("span",B,m(t.text),1)],4)],544))}});const I=w(h,[["__scopeId","data-v-74636348"]]);export{I as T};
//# sourceMappingURL=Tooltip.93a1d641.js.map
