import"./outputWidgets.04a14374.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[i]="e434e58a-5f96-44a6-9b6c-19e4008b0acc",e._sentryDebugIdIdentifier="sentry-dbid-e434e58a-5f96-44a6-9b6c-19e4008b0acc")}catch{}})();function c(e,i){const a=document,n=e.matched.slice().reverse().find(t=>t.meta&&t.meta.title),s=i.matched.slice().reverse().find(t=>t.meta&&t.meta.metaTags);n?a.title=n.meta.title:s&&(a.title=s.meta.title)}export{c as u};
//# sourceMappingURL=index.5d9ba614.js.map
