import{T as e,A as t}from"./TabPane.86c1aa22.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[f]="31409cac-8943-4523-863f-7945cf8096c6",n._sentryDebugIdIdentifier="sentry-dbid-31409cac-8943-4523-863f-7945cf8096c6")}catch{}})();e.TabPane=t;e.install=function(n){return n.component(e.name,e),n.component(t.name,t),n};
//# sourceMappingURL=index.2290d02f.js.map
