import{t,b as s,eu as o}from"./outputWidgets.04a14374.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="442a0b20-b672-4cb1-9a1e-67bc7f4d48d0",e._sentryDebugIdIdentifier="sentry-dbid-442a0b20-b672-4cb1-9a1e-67bc7f4d48d0")}catch{}})();const r={},a={class:"organization-settings"};function d(e,n){return s(),o("div",a,"Organization settings")}const f=t(r,[["render",d]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.f6125785.js.map
