import{E as f,G as l}from"./outputWidgets.04a14374.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="f8f695fb-03cd-40fd-b415-db1fe0d8d7c4",r._sentryDebugIdIdentifier="sentry-dbid-f8f695fb-03cd-40fd-b415-db1fe0d8d7c4")}catch{}})();const i=r=>{const e=f({loading:!0,result:null,error:null}),n=t=>(e.value={loading:!1,result:t,error:null},t),s=t=>{e.value={loading:!1,result:null,error:t}},o=async()=>(e.value={loading:!0,result:e.value.result,error:null},r().then(n).catch(s));o();const u=l(()=>e.value.loading),d=l(()=>e.value.result),a=l(()=>e.value.error);return{loading:u,result:d,error:a,refetch:o}};export{i as a};
//# sourceMappingURL=asyncComputed.53598080.js.map
