import{d as f,eB as u,G as b,b as y,c as g,u as _}from"./outputWidgets.04a14374.js";import{a as w}from"./asyncComputed.53598080.js";import"./router.4677d467.js";import{M as n}from"./member.f68ae2a2.js";import"./columns.19f4f485.js";import{C as I}from"./CrudView.a6f509b7.js";import"./Base.0c1843db.js";import"./transButton.772cc0ed.js";import"./Text.84d5ffc7.js";import"./Title.9beb186f.js";import"./index.5d9ba614.js";import"./gateway.f7d4a0c5.js";import"./record.b64a41e6.js";import"./pubsub.bb759777.js";import"./icons.dee9dbe8.js";import"./url.311573c2.js";import"./index.9bdc1e6b.js";import"./index.90d3343e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="78df9b23-1f55-4ca0-9656-bd31fe9cdf16",e._sentryDebugIdIdentifier="sentry-dbid-78df9b23-1f55-4ca0-9656-bd31fe9cdf16")}catch{}})();const q=f({__name:"Members",setup(e){const r=u().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(r,t.email),p()},{loading:l,result:d,refetch:p}=w(()=>n.list(r)),c=b(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=d.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{q as default};
//# sourceMappingURL=Members.d425276f.js.map
