import{S as p}from"./Sidebar.86b761c3.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.711d9ac2.js";import{u as l,v as u,x as d}from"./icons.dee9dbe8.js";import{d as b,eB as f,G as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.04a14374.js";import{a as w}from"./asyncComputed.53598080.js";import"./router.4677d467.js";import{O as z}from"./organization.2fe75ceb.js";import"./columns.19f4f485.js";import{B as h}from"./BaseLayout.bcc765e4.js";import"./Tooltip.93a1d641.js";import"./logo.084e5d7c.js";import"./index.164bca62.js";import"./transButton.772cc0ed.js";import"./Text.84d5ffc7.js";import"./Base.0c1843db.js";import"./Title.9beb186f.js";import"./index.5d9ba614.js";import"./gateway.f7d4a0c5.js";import"./record.b64a41e6.js";import"./pubsub.bb759777.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="5afb3506-a00f-4922-9ec7-f3e5e7e12230",e._sentryDebugIdIdentifier="sentry-dbid-5afb3506-a00f-4922-9ec7-f3e5e7e12230")}catch{}})();const J=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:u,path:"members"},{name:"Billing",icon:d,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{J as default};
//# sourceMappingURL=Organization.e752398a.js.map
