import{d,eB as b,G as m,a as f,b as g,c as v,w as i,f as s}from"./outputWidgets.04a14374.js";import{B as _}from"./BaseLayout.bcc765e4.js";import{a as h}from"./asyncComputed.53598080.js";import{P as y}from"./project.e6570f82.js";import"./router.4677d467.js";import{O as z}from"./organization.2fe75ceb.js";import"./columns.19f4f485.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.711d9ac2.js";import{S as I}from"./Sidebar.86b761c3.js";import{y as w,z as B,A as k,B as C,C as P,q as $,D as x,E as D,u as M,v as O,x as S}from"./icons.dee9dbe8.js";import"./gateway.f7d4a0c5.js";import"./record.b64a41e6.js";import"./pubsub.bb759777.js";import"./Base.0c1843db.js";import"./transButton.772cc0ed.js";import"./Text.84d5ffc7.js";import"./Title.9beb186f.js";import"./index.5d9ba614.js";import"./logo.084e5d7c.js";import"./index.164bca62.js";import"./Tooltip.93a1d641.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="1ff6886b-51e0-4515-9d5f-2cdb5f3e9c7e",o._sentryDebugIdIdentifier="sentry-dbid-1ff6886b-51e0-4515-9d5f-2cdb5f3e9c7e")}catch{}})();const oe=d({__name:"Project",setup(o){const c=b().params.projectId,{result:e}=h(()=>y.get(c).then(async a=>{const t=await z.get(a.organizationId);return{project:a,organization:t}})),l=m(()=>{var a,t,n,p;return((a=e.value)==null?void 0:a.organization)&&e.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=e.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=e.value)==null?void 0:p.organization.id}`},{label:e.value.project.name,path:`/projects/${e.value.project.id}`}]:void 0}),u=m(()=>{var a;return(a=e.value)!=null&&a.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:w},{name:"Connectors",path:"connectors",icon:B},{name:"Tables",path:"tables",icon:k},{name:"API Keys",path:"api-keys",icon:C},{name:"Env Vars",path:"env-vars",icon:P},{name:"Files",path:"files",icon:$},{name:"Logs",icon:x,path:"logs",beta:!0},{name:"Settings",icon:D,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:M,path:`/organizations/${e.value.project.organizationId}/projects`},{name:"Members",icon:O,path:`/organizations/${e.value.project.organizationId}/members`},{name:"Billing",icon:S,path:`/organizations/${e.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(a,t)=>{const n=f("router-view");return g(),v(_,null,{content:i(()=>[s(n)]),navbar:i(()=>[s(j,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:i(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{oe as default};
//# sourceMappingURL=Project.b454f42d.js.map
